@@ -4,25 +4,15 @@
  * Copyright (c) 1992 Branko Lankester
  *
  */
-#define __KERNEL__
 #include <sys/types.h>
-#include <termios.h>
-#include <stdio.h>
 #include <unistd.h>
-#include <stdlib.h>
-#include <string.h>
-#include <pwd.h>
-#include <errno.h>
-#include <ctype.h>
-#include <time.h>
-#include <sys/ioctl.h>
-#include <linux/sched.h>
-#include <linux/ptrace.h>
 #include <fcntl.h>
+#include <termios.h>
 #include <limits.h>
+#include <string.h>
+#include <linux/sched.h>
 #include "ps.h"
 
-
 #define	MAX_SWAPFILES	8
 
 #define	STKBUF	2048	/* must be bigger than MAXCMD */
@@ -38,10 +28,8 @@ static int swapread(void *buf, int swap_nr, off_t pos, int n);
 char *
 cmd_args(struct task_struct *task)
 {
-    unsigned long st_stk;	/* virtual address of data in buf */
-    static unsigned long buf[STKBUF/4 + 8]; 
-    int i, n;
-    int argc, argv0;
+    static char buf[STKBUF]; 
+    int n;
     char *p, *commline;
 
     if (task == NULL)
@@ -57,61 +45,14 @@ cmd_args(struct task_struct *task)
     if (task->pid == 0)
 	return("scheduler");
     
-    st_stk = task->mm->start_stack;
-    if ((n = vmread(buf, task->tss.cr3, task->mm->start_code + st_stk, STKBUF)) <= 0)
+    if ((n = vmread(buf, task->tss.cr3, task->mm->arg_start, STKBUF)) <= 0)
 	goto bad;
 
-    argc = buf[0];
-    if (argc <= 0 || argc + 3 >= n/4 || buf[argc + 3] != 0) {
-	int envp = buf[2];
-	if (envp > st_stk + 16 && envp < TASK_SIZE)
-	    argc = (envp - st_stk - 16) / 4;
-	else {
-	    for (i = 3; i < n/4; ++i) {
-		int badp = 0;
-		if (buf[i] == 0) break;
-		if (buf[i] < st_stk || buf[i] >= TASK_SIZE)
-		    if (++badp == 4)
-			goto bad;
-	    }
-	    argc = i - 3;
-	}
-    }
-    if (argc == 0)
-	goto bad;
-
-    argv0 = buf[3];
-    if (argv0 < st_stk + 24 || argv0 > TASK_SIZE) {
-	for (i = argc + 4; i < n/4; ++i)
-	    if (buf[i] == 0) break;
-	if (buf[i] != 0)
-	    goto bad;
-	argv0 = st_stk + i*4 + 8;
-    }
-    if (argv0 - st_stk + maxcmd + 1 > STKBUF) {
-	/*
-	 * arg strings not in buffer
-	 * read some bytes before argv[0] to find the real start
-	 * value of argv[0] (prog may have incremented argv[0])
-	 */
-	st_stk = argv0 - 16;
-	n = vmread(buf, task->tss.cr3, task->mm->start_code + st_stk, maxcmd+16);
-	if ((n -= 16) <= 0)
-	    goto bad;
-    } else {
-	n -= (argv0 - st_stk) + 4;	/* 4 last bytes always 0 */
-    }
-    p = (char *) buf + argv0 - st_stk;
-    for (i = 0; i < 16; ++i)
-	if (*--p == '\0')
-	    break;
-    if (*p != '\0')
-	p += 16;
-    else {
-	n += i;
-	++p;
-    }
-
+    if (show_env)
+	n = task->mm->env_end - task->mm->arg_start;
+    else
+	n = task->mm->arg_end - task->mm->arg_start;
+    p = &buf[0];
     if (maxcmd < n)
 	n = maxcmd;
     commline = p;
@@ -120,7 +61,7 @@ cmd_args(struct task_struct *task)
 	for (; *p != '\0'; ++p)
 	    if (*p < ' ' || *p > '\176')
 		*p = ' ';
-	if (p < commline + n && (--argc > 0 || show_env))
+	if (p < commline + n)
 	    *p = ' ';
 	else
 	    break;
