@@ -19,6 +19,7 @@
 #include <sys/ioctl.h>
 #include <linux/sched.h>
 #include <linux/ptrace.h>
+#include <asm/page.h>
 #include "ps.h"
 #include "psdata.h"
 
@@ -51,11 +52,11 @@ char *hdrs[] = {
 typedef void format_function(char *s, struct task_struct *task, reg_t *stack);
 
 format_function show_short, show_long, show_user, show_jobs,
-	show_sig, show_vm, show_m, show_regs, show_syscall;
+	show_sig, show_vm, show_m, show_registers, show_syscall;
 
 format_function *fmt_fnc[] = {
     show_short, show_long, show_user, show_jobs,
-    show_sig, show_vm, show_m, show_regs, show_syscall,
+    show_sig, show_vm, show_m, show_registers, show_syscall,
 };
 
 char *sighdrs[] = {
@@ -602,7 +603,7 @@ show_vm(char *s, struct task_struct *task, reg_t *stack)
     if (task->rlim[RLIMIT_RSS].rlim_cur == RLIM_INFINITY)
 	s += sprintf(s, "   xx ");
     else
-	s += sprintf(s, "%5d ", task->rlim[RLIMIT_RSS].rlim_cur / 1024);
+	s += sprintf(s, "%5ld ", (long) task->rlim[RLIMIT_RSS].rlim_cur / 1024);
     pmem = task->mm->rss * 1000 / nr_pages;
     sprintf(s, "%2d.%d", pmem / 10, pmem % 10);
 }
@@ -651,7 +652,7 @@ prtime(char *s, long unsigned int t, long unsigned int rel)
 }
 
 void
-show_regs(char *s, struct task_struct *task, reg_t *stack)
+show_registers(char *s, struct task_struct *task, reg_t *stack)
 {
     char time1[16];
     char time2[16];
